==> dojo-1.9.4.tgz: package/cldr/nls/ar/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "E، d MMM، y G",
	"field-dayperiod": "ص/م",
	"field-minute": "الدقائق",
	"dateFormatItem-MMMEd": "E، d MMM",
	"dateTimeFormat-full": "{1} {0}",
	"field-day-relative+-1": "أمس",
	"dateFormatItem-hms": "h:mm:ss a",
	"field-day-relative+-2": "أول أمس",
	"field-weekday": "اليوم",
	"dateFormatItem-MMM": "LLL",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Gy": "y G",
	"dateTimeFormat-medium": "{1} {0}",
	"field-era": "العصر",
	"field-hour": "الساعات",
	"dateFormatItem-y": "y G",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-Ed": "E، d",
	"field-day-relative+0": "اليوم",
	"field-day-relative+1": "غدًا",
	"field-day-relative+2": "بعد الغد",
	"dateFormatItem-GyMMMd": "d MMM، y G",
	"dateFormatItem-yyyyMMMM": "MMMM y G",
	"dateFormat-long": "d MMMM، y G",
	"field-zone": "التوقيت",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+-1": "الأسبوع الماضي",
	"dateFormat-medium": "dd‏/MM‏/y G",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-year-relative+0": "هذه السنة",
	"field-year-relative+1": "السنة التالية",
	"field-year-relative+-1": "السنة الماضية",
	"dateFormatItem-ms": "mm:ss",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-year": "السنة",
	"dateTimeFormat-long": "{1} {0}",
	"field-week": "الأسبوع",
	"dateFormatItem-yyyyMd": "d‏/M‏/y G",
	"dateFormatItem-yyyyMMMd": "d MMM، y G",
	"dateFormatItem-yyyyMEd": "E، d/‏M/‏y G",
	"dateFormatItem-MMMd": "d MMM",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي",
	"field-month-relative+0": "هذا الشهر",
	"dateFormatItem-H": "HH",
	"field-month": "الشهر",
	"field-month-relative+1": "الشهر التالي",
	"dateFormatItem-M": "L",
	"field-second": "الثواني",
	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-day": "يوم",
	"dateFormatItem-MEd": "E، d/M",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormatItem-hm": "h:mm a",
	"dateFormat-short": "d‏/M‏/y GGGGG",
	"dateFormatItem-yyyyM": "M‏/y G",
	"dateFormat-full": "EEEE، d MMMM، y G",
	"dateFormatItem-Md": "d/‏M",
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-d": "d",
	"field-month-relative+-1": "الشهر الماضي",
	"dateFormatItem-h": "h a"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/ar/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "الآن",
	"field-weekday": "اليوم",
	"field-wed-relative+0": "الأربعاء الحالي",
	"field-wed-relative+1": "الأربعاء التالي",
	"dateFormatItem-GyMMMEd": "E، d MMM، y G",
	"dateFormatItem-MMMEd": "E، d MMM",
	"field-tue-relative+-1": "الثلاثاء الماضي",
	"dateFormat-long": "d MMMM، y G",
	"field-fri-relative+-1": "الجمعة الماضية",
	"field-wed-relative+-1": "الأربعاء الماضي",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1} {0}",
	"dateFormat-full": "EEEE، d MMMM، y G",
	"dateFormatItem-yyyyMEd": "E، d/‏M/‏y G",
	"field-thu-relative+-1": "الخميس الماضي",
	"dateFormatItem-Md": "d/‏M",
	"field-era": "العصر",
	"field-year": "السنة",
	"dateFormatItem-yyyyMMMM": "MMMM، y G",
	"field-hour": "الساعات",
	"field-sat-relative+0": "السبت الحالي",
	"field-sat-relative+1": "السبت التالي",
	"field-day-relative+0": "اليوم",
	"field-day-relative+1": "غدًا",
	"field-thu-relative+0": "الخميس الحالي",
	"dateFormatItem-GyMMMd": "d MMM، y G",
	"field-day-relative+2": "بعد الغد",
	"field-thu-relative+1": "الخميس التالي",
	"dateFormatItem-H": "HH",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E، d MMM، y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "MMM، y G",
	"dateFormatItem-yyyyMMMd": "d MMM، y G",
	"field-sun-relative+0": "الأحد الحالي",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "الأحد التالي",
	"field-minute": "الدقائق",
	"field-dayperiod": "ص/م",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+-1": "أمس",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "أول أمس",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E، d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "الجمعة الحالية",
	"field-fri-relative+1": "الجمعة التالية",
	"field-day": "يوم",
	"field-zone": "التوقيت",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "السنة الماضية",
	"field-month-relative+-1": "الشهر الماضي",
	"dateFormatItem-hm": "h:mm a",
	"dateFormatItem-yyyyMd": "d‏/M‏/y G",
	"field-month": "الشهر",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "الثلاثاء الحالي",
	"field-tue-relative+1": "الثلاثاء التالي",
	"field-mon-relative+0": "الاثنين الحالي",
	"field-mon-relative+1": "الاثنين التالي",
	"dateFormat-short": "d‏/M‏/y GGGGG",
	"field-second": "الثواني",
	"field-sat-relative+-1": "السبت الماضي",
	"field-sun-relative+-1": "الأحد الماضي",
	"field-month-relative+0": "هذا الشهر",
	"field-month-relative+1": "الشهر التالي",
	"dateFormatItem-Ed": "E، d",
	"field-week": "الأسبوع",
	"dateFormat-medium": "dd‏/MM‏/y G",
	"field-year-relative+0": "السنة الحالية",
	"field-week-relative+-1": "الأسبوع الماضي",
	"dateFormatItem-yyyyM": "M‏/y G",
	"field-year-relative+1": "السنة التالية",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "الاثنين الماضي",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "هذا الأسبوع",
	"field-week-relative+1": "الأسبوع التالي"
}
//end v1.x content
);
